<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

class TheLeftSidebar extends componentEntity
{
    public function __construct()
    {
        parent::__construct();
        $this->setColWidth('md', 4)
            ->setColWidth('lg', 3)
            ->setColWidth('xl', 2);
    }
}
