<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

class Content extends componentEntity
{
    public function __construct()
    {
        parent::__construct();
        $this->setColWidth('lg', 9)
            ->setColWidth('md', 8)
            ->setColWidth('xl', 10);
    }

    public function addDataSrc($dataSrc)
    {
        $this->addProperty('dataSrc', $dataSrc);
    }
}
